Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'source/blender/editors/space_api')
-rw-r--r--source/blender/editors/space_api/spacetypes.c28
1 files changed, 14 insertions, 14 deletions
diff --git a/source/blender/editors/space_api/spacetypes.c b/source/blender/editors/space_api/spacetypes.c
index 37f5ed642fe..7246812dc82 100644
--- a/source/blender/editors/space_api/spacetypes.c
+++ b/source/blender/editors/space_api/spacetypes.c
@@ -129,22 +129,22 @@ void ED_spacetypes_init(void)
ED_screen_user_menu_register();
- /* manipulator types */
- ED_manipulatortypes_button_2d();
- ED_manipulatortypes_dial_3d();
- ED_manipulatortypes_grab_3d();
- ED_manipulatortypes_arrow_2d();
- ED_manipulatortypes_arrow_3d();
- ED_manipulatortypes_primitive_3d();
- ED_manipulatortypes_cage_2d();
- ED_manipulatortypes_cage_3d();
-
- /* register types for operators and manipulators */
+ /* gizmo types */
+ ED_gizmotypes_button_2d();
+ ED_gizmotypes_dial_3d();
+ ED_gizmotypes_grab_3d();
+ ED_gizmotypes_arrow_2d();
+ ED_gizmotypes_arrow_3d();
+ ED_gizmotypes_primitive_3d();
+ ED_gizmotypes_cage_2d();
+ ED_gizmotypes_cage_3d();
+
+ /* register types for operators and gizmos */
spacetypes = BKE_spacetypes_list();
for (type = spacetypes->first; type; type = type->next) {
- /* init manipulator types first, operator-types need them */
- if (type->manipulators) {
- type->manipulators();
+ /* init gizmo types first, operator-types need them */
+ if (type->gizmos) {
+ type->gizmos();
}
if (type->operatortypes) {
type->operatortypes();